@@ -1,7 +1,7 @@
 import json
 
 class GrammarError(Exception):
-    def __init__(self, valor="Could not solve the grammar error", data=None):
+    def __init__(self, data=None, valor="Could not solve the grammar error"):
         self.valor = valor
         self.data = data
     def __repr__(self):
@@ -10,10 +10,10 @@ class GrammarError(Exception):
             'data': self.data
         }
     def __str__(self):
-        return self.__repr__()
+        return self.valor
 
 class SintaticError(Exception):
-    def __init__(self, valor="Could not solve the sintatic error", data=None):
+    def __init__(self, data=None, valor="Could not solve the sintatic error"):
         self.valor = valor
         self.data = data
     def __repr__(self):
@@ -22,10 +22,10 @@ class SintaticError(Exception):
             'data': self.data
         }
     def __str__(self):
-        return self.__repr__()
+        return self.valor
 
 class LexicalError(Exception):
-    def __init__(self, valor="Could not solve the lexical error", data=None):
+    def __init__(self, data=None, valor="Could not solve the lexical error"):
         self.valor = valor
         self.data = data
     def __repr__(self):
@@ -34,4 +34,4 @@ class LexicalError(Exception):
             'data': self.data
         }
     def __str__(self):
-        return self.__repr__()
+        return self.valor
\ No newline at end of file
