@@ -101,8 +101,6 @@ class CheckSintax():
 
             if second_yacc_error_list:
 
-                # second_yacc_error_list = self.__get_only_current_error(second_yacc_error_list)
-
                 if second_yacc_error_list[0]['lexpos'] == None: # EOF ?
                     second_yacc_error_list.reverse()
                     second_yacc_error_list.pop()
@@ -123,7 +121,7 @@ class CheckSintax():
                     'pure_yacc_errors_list': self.pure_yacc_errors
                 })
 
-        elif self.yacc_error_list and attempts >= 3:
+        elif self.yacc_error_list and self.attempts >= 3:
             raise GrammarError({
                     'error': grammar_errors,
                     'latex': self.latex,
@@ -154,24 +152,6 @@ class CheckSintax():
             for token in token_errors_history:
                 self.symbols_attempts_in_lex.extend(token['attempts'])
 
-    def __get_only_current_error(self, second_yacc_error_list):
-        """Se erro novo for EOF ou se for em uma posição diferente do PRIMEIRO símbolo com erro')
-        Remove erro da lista. Para resolver apenas o erro atual / primeiro erro | usa sempre index=0
-        """
-        cond = False
-        if isinstance(second_yacc_error_list[self.index], dict):
-            helpers.debug('Syntactic error')
-            cond = second_yacc_error_list[self.index]['lexpos'] != None and second_yacc_error_list[0]['lexpos'] != self.yacc_error_list[0]['lexpos']
-        if isinstance(second_yacc_error_list[self.index], tuple):
-            helpers.debug('Lex error')
-            cond = second_yacc_error_list[self.index][1] != -1 and second_yacc_error_list[self.index][1] != self.yacc_error_list[self.index]['lexpos']
-        if cond:
-            # Remove último erro adicionado para manter no anterior
-            second_yacc_error_list.reverse()
-            second_yacc_error_list.pop()
-            second_yacc_error_list.reverse()
-        return second_yacc_error_list
-
     def __attempt_to_fix_error(self, grammar_errors):
         helpers.debug('[check_grammar_sintax.py] __attempt_to_fix_error()')
         bg = base_grammar.BaseGrammar()
