@@ -16,7 +16,7 @@ def LatexParse(latex):
         acceptance.append('p_el_er_eq_er')
 
     def p_el_er_neq_er(p):
-        'EL : ER  NEQ ER'
+        'EL : ER NEQ ER'
         acceptance.append('p_el_er_neq_er')
 
     def p_el_er_eq(p):
@@ -28,8 +28,6 @@ def LatexParse(latex):
         acceptance.append('p_el_er_neq')
 
     def p_el_er(q):
-        'EL : PLUS ER'
-        'EL : MINUS ER'
         'EL : ER'
         acceptance.append('p_el_er')
 
@@ -85,6 +83,14 @@ def LatexParse(latex):
         'S : S F'
         acceptance.append('p_s_f')
 
+    def p_s_plus_f(p):
+        'S : PLUS F'
+        acceptance.append('p_s_lus_f')
+
+    def p_s_min_f(p):
+        'S : MIN F'
+        acceptance.append('p_s_min_f')
+
     def p_s_f(p):
         'S : F'
         acceptance.append('p_s_f')
