@@ -21,8 +21,10 @@ class Parser:
             self.tree=tree
 
             tlist = self.__tree_to_list(tree)
+
             self.tlist = tlist
             latex_before_cg = self.__list_to_latex_obj(tlist)
+            # print('\nlatex_before_cg: ', latex_before_cg)
 
             check_grammar = cg.CheckGrammar()
             latex = check_grammar.check(latex_before_cg)
@@ -56,18 +58,11 @@ class Parser:
 
         R = [[0,0], [9999999999, 9999999999]]
         sstart = self.__sp(listin, R)
-        helpers.debug('[parser.py] __main_parsing() | starting symbol index: %d ' % sstart)
-        helpers.debug('[parser.py] __main_parsing() | starting symbol label: %s ' % listin[sstart]['label'])
+        helpers.debug('\n[parser.py] __main_parsing() | STARTING symbol index: %d ' % sstart)
+        helpers.debug('[parser.py] __main_parsing() | STARTING symbol label: %s ' % listin[sstart]['label'])
 
         s = listin[sstart]
 
-        R = [
-            [s['wall']['left'], s['wall']['top']],
-            [s['wall']['right'], s['wall']['bottom']]
-        ]
-        helpers.debug('[parser.py] __main_parsing() | first region [R]:')
-        helpers.debug(R)
-
         if sstart != -1:
 
             Q.enqueue(sstart)
@@ -75,42 +70,100 @@ class Parser:
             listin[sstart]['checked'] = True
 
         while not Q.is_empty():
+            '''
+            abc^{2-1}
+            =============     ->    | EOBL  |
+                       a            | c  |
+            =============           | b |
+                                    | a |
+            '''
 
+            '''
+            abc^{2-1]
+            =============     ->    |   |
+                        2           |   |
+            =============           | - |
+                                    | 2 |
+            '''
             helpers.debug('\n[parser.py] __main_parsing() | find main baseline')
             while not Q.is_empty():
-                temp1 = Q.dequeue()
+                temp1 = Q.dequeue()  # a, 2
                 ParentNode = Q.dequeue()
                 SymbolNode = DS.SymbolNode(listin[temp1])
                 T.insert(SymbolNode, ParentNode, 'Node')
-                S.push(temp1)
+                S.push(temp1) # a, 2
                 S.push(SymbolNode)
 
-                temp2 = self.__hor(listin, temp1)
+                print('\n[parser.py] __main_parsing() | find baseline of symbol: ', temp1, listin[temp1]['label'])
+
+                helpers.debug('\n[parser.py] __main_parsing() | temp2 hor...')
+                temp2 = self.__hor(listin, temp1) # b, -
+                print('\n[parser.py] __main_parsing() | temp2: ', temp2, listin[temp2]['label'])
 
                 while temp2 != -1:
+                    print('[parser.py] __main_parsing() | ... while temp2')
                     listin[temp2]['checked'] = True
+                    print('[parser.py] __main_parsing() |  ...wall attributes of temp1: ', listin[temp1]['wall'])
                     listin[temp2]['wall'] = listin[temp1]['wall'].copy()
+                    '''
+                    a.wall = -1 -1 9999 9999
+
+                    b.checked = true
+                    b.wall = a.wall (-1 -1 9999 9999)
+
+                    c.checked = true
+                    c.wall = b.wall
+                    ---------------------------------------------
+                    -.checked = true 
+                    -.wall = 2.wall (wall da região super?)
+
+                    '''
+                    print('[parser.py] __main_parsing() | ...wall attributes of temp2: ', listin[temp2]['wall'])
                     SymbolNode = DS.SymbolNode(listin[temp2])
                     T.insert(SymbolNode, ParentNode, 'Node')
                     S.push(temp2)
                     S.push(SymbolNode)
                     listin[temp1]['wall']['right'] = listin[temp2]['xmin']
-                    temp1 = temp2
-                    temp2 = self.__hor(listin, temp1)
+                    '''
+                    a.wall.right = b.xmin
+                    b.wall.right = c.xmin
+                    '''
+                    print('[parser.py] __main_parsing() | ...updated wall attributes of temp1: ', listin[temp1]['wall'])
+                    temp1 = temp2 # b
+                    temp2 = self.__hor(listin, temp1) # c - 1
+                    print('[parser.py] __main_parsing() | new temp2: ', temp2)
             S.push("EOBL")
 
             helpers.debug('\n[parser.py] __main_parsing() | find secondary baseline')
+
+            '''
+            abc^2
+            =============     ->    | EOBL  |
+                        2           | c  |
+            =============           | b |
+                                    | a |
+            '''
             while not S.is_empty():
                 if S.peek() == "EOBL":
                     S.pop()
                 SymbolNode = S.pop()
-                temp1 = S.pop()
+                temp1 = S.pop() # c
+
+                helpers.debug('[parser.py] __main_parsing() | symbol: %s ' % temp1)
 
                 upperThreshold = listin[temp1]['ymin'] + ((1/6) * listin[temp1]['h'])
                 lowerThreshold = listin[temp1]['ymin'] + ((5/6) * listin[temp1]['h'])
 
                 helpers.debug('[parser.py] __main_parsing() | temp1 label: %s' % listin[temp1]['label'])
 
+                '''
+                HOW TO?
+                set the rightWall attribute of s i to the minX coordinate of s i+1
+                set the leftWall attribute of s i to the symbols' minX coordinate.
+                set the topWall attribute of s i to RmaxY
+                set the bottomWall attribute of s i to RminY
+                '''
+
                 R = [
                     {'above': [
                         [listin[temp1]['xmin'], listin[temp1]['wall']['top']],
@@ -125,20 +178,29 @@ class Parser:
                 for region in R:
                     # Para cada região, busca o símbolo inicial
                     reg = region[list(region.keys())[0]]
-                    temp2 = self.__start(listin, reg)
+                    region_name = list(region.keys())[0]
+                    helpers.debug('\n[parser.py] __main_parsing() | região: %s' % region_name)
 
-                    if temp2 != -1:
-                        if not listin[temp2]['checked']:
-                            listin[temp2]['checked'] = True
-                            listin[temp2]['wall']['left'] = reg[0][0]
-                            listin[temp2]['wall']['right'] = reg[1][0]
-                            listin[temp2]['wall']['top'] = reg[0][1]
-                            listin[temp2]['wall']['bottom'] = reg[1][1]
+                    label = int(listin[temp1]['label'])
+                    # ( ) [ ] { } . * = neq + sqrt
+                    operators = bool(label in range(11,17) or label in range(27,31) or label == 17 or label == 23)
 
-                            RelationNode = DS.RegionNode(list(region.keys())[0])
-                            T.insert(RelationNode, SymbolNode, 'Node')
-                            Q.enqueue(temp2)
-                            Q.enqueue(RelationNode)
+                    if (region_name == 'above' and not operators) or (region_name == 'below' and not operators):
+
+                        temp2 = self.__start(listin, reg)
+
+                        if temp2 != -1:
+                            if not listin[temp2]['checked']:
+                                listin[temp2]['checked'] = True
+                                listin[temp2]['wall']['left'] = reg[0][0]
+                                listin[temp2]['wall']['right'] = reg[1][0]
+                                listin[temp2]['wall']['top'] = reg[0][1]
+                                listin[temp2]['wall']['bottom'] = reg[1][1]
+
+                                RelationNode = DS.RegionNode(list(region.keys())[0])
+                                T.insert(RelationNode, SymbolNode, 'Node')
+                                Q.enqueue(temp2)
+                                Q.enqueue(RelationNode)
 
                 R = [
                     {'super': [
@@ -158,20 +220,31 @@ class Parser:
                 for region in R:
                     # Para cada região, busca o símbolo inicial
                     reg = region[list(region.keys())[0]]
-                    temp2 = self.__start(listin, reg)
+                    region_name = list(region.keys())[0]
+                    helpers.debug('\n[parser.py] __main_parsing() | região: %s' % region_name)
 
-                    if temp2 != -1:
-                        if not listin[temp2]['checked']:
-                            listin[temp2]['checked'] = True
-                            listin[temp2]['wall']['left'] = reg[0][0]
-                            listin[temp2]['wall']['right'] = reg[1][0]
-                            listin[temp2]['wall']['top'] = reg[0][1]
-                            listin[temp2]['wall']['bottom'] = reg[1][1]
+                    label = int(listin[temp1]['label'])
+                    # - ( ) [ ] { } . * = neq +
+                    operators = bool(label == 10 or label in range(27,31) or label == 17)
 
-                            RelationNode = DS.RegionNode(list(region.keys())[0])
-                            T.insert(RelationNode, SymbolNode, 'Node')
-                            Q.enqueue(temp2)
-                            Q.enqueue(RelationNode)
+                    if (region_name == 'super' and not operators) or \
+                        (region_name == 'subsc' and not operators) or \
+                        (region_name == 'contains' and int(listin[temp1]['label']) == 23):
+
+                        temp2 = self.__start(listin, reg)
+
+                        if temp2 != -1:
+                            if not listin[temp2]['checked']:
+                                listin[temp2]['checked'] = True
+                                listin[temp2]['wall']['left'] = reg[0][0]
+                                listin[temp2]['wall']['right'] = reg[1][0]
+                                listin[temp2]['wall']['top'] = reg[0][1]
+                                listin[temp2]['wall']['bottom'] = reg[1][1]
+
+                                RelationNode = DS.RegionNode(list(region.keys())[0])
+                                T.insert(RelationNode, SymbolNode, 'Node')
+                                Q.enqueue(temp2) # ²=2
+                                Q.enqueue(RelationNode)
 
         return T
 
@@ -180,6 +253,11 @@ class Parser:
         xmin_sorted = sorted(symbols, key = lambda i: i['xmin'])
         symbols = xmin_sorted
 
+        # for debuggind
+        for t in xmin_sorted:
+            if not isinstance(t, str):
+                del t['image']
+
         for i in range(0,len(symbols)):
             s = symbols[i]
             s['centroid'] = list(s['centroid'])
@@ -212,7 +290,7 @@ class Parser:
         return symbols
 
     def __overlap(self, symbolIndex, top, bottom, listin):
-        helpers.debug('[parser.py] __overlap()')
+        helpers.debug('\n\n[parser.py] __overlap()')
         listIndex = symbolIndex
         stop = False
         n = len(listin)
@@ -230,25 +308,40 @@ class Parser:
         helpers.debug('[parser.py] __overlap() | maxLength: %d ' % maxLength)
 
         while listIndex > 0 and stop == False:
-            if listin[listIndex-1]['xmin'] < listin[symbolIndex]['xmin']:
-                stop = True
-            else:
+            print('[parser.py] __overlap() | ', listin[listIndex-1]['xmin'], listin[symbolIndex]['xmin'])
+            if listin[listIndex-1]['xmin'] <= listin[symbolIndex]['xmin']:
                 listIndex = listIndex - 1
+                # stop = True
+            else:
+                # listIndex = listIndex - 1
+                stop = True
+
+        helpers.debug('[parser.py] __overlap() | listIndex: %d ' % listIndex)
+        helpers.debug('[parser.py] __overlap() | n: %d ' % n)
+        helpers.debug('[parser.py] __overlap() | top: %d ' % top)
+        helpers.debug('[parser.py] __overlap() | bottom: %d ' % bottom)
+        # helpers.debug('[parser.py] __overlap() | list ')
+        # print(listin)
 
         while listIndex < n and listin[listIndex]['xmin'] < listin[symbolIndex]['xmax']:
 
+            print('[parser.py] __overlap() | ... label: ', listin[listIndex]['label'])
             # symbol '10' '-'
             if not listin[listIndex]['checked'] and \
                 listin[listIndex]['label'] == '10' and \
                 listin[listIndex]['centroid'][1] >= top and \
                 listin[listIndex]['centroid'][1] <= bottom and \
-                listin[listIndex]['xmin'] <= (listin[symbolIndex]['xmin'] + 8) and \
+                listin[listIndex]['xmin'] <= (listin[symbolIndex]['xmin']) and \
                 (listin[listIndex]['xmax'] - listin[listIndex]['xmin']) > maxLength:
                     maxLength = (listin[listIndex]['xmax'] - listin[listIndex]['xmin'])
                     mainLine = listIndex
 
             listIndex += 1
 
+        helpers.debug('[parser.py] __overlap() | listIndex: %d ' % listIndex)
+        helpers.debug('[parser.py] __overlap() | mainLine: %d ' % mainLine)
+        helpers.debug('[parser.py] __overlap() | maxLength: %d ' % maxLength)
+
         if mainLine == -1:
             return symbolIndex
         else:
@@ -256,8 +349,7 @@ class Parser:
 
     def __start(self, listin, R):
         helpers.debug('\n[parser.py] __start()')
-        helpers.debug('[parser.py] region [R]: ')
-        helpers.debug(R)
+        print('[parser.py] __start() | region [R]: ', R)
 
         # Adicionei o round()
         left = round(R[0][0])
@@ -265,7 +357,7 @@ class Parser:
         right = round(R[1][0])
         bottom = round(R[1][1])
 
-        helpers.debug('[parser.py] rounded region [R]: left: %d, right: %d, top: %d, bottom: %d' %
+        helpers.debug('[parser.py] __start() | rounded region [R]: left: %d, right: %d, top: %d, bottom: %d' %
             (left, right, top, bottom)
         )
 
@@ -275,8 +367,9 @@ class Parser:
         n = len(listin)
 
         while leftmostIndex == -1 and listIndex < n:
-            helpers.debug('[parser.py] ... symbol index: %d' % listIndex)
-            helpers.debug('[parser.py] ... symbol label: %s' % listin[listIndex]['label'])
+            helpers.debug('[parser.py] __start() | ... symbol index: %d' % listIndex)
+            helpers.debug('[parser.py] __start() | ... symbol label: %s' % listin[listIndex]['label'])
+            print('[parser.py]__start() | ... symbol centroid: ', listin[listIndex]['centroid'])
 
             # Adicionei o round()
             # Adicionei o >=, <=,... - era >, <,...
@@ -301,44 +394,66 @@ class Parser:
         return self.__start(listin, R)
 
     def __hor(self, listin, index):
-        helpers.debug('\n[parser.py] __hor()')
-        if listin[index]['type'] == 'Open':
-            left = listin[index]['wall']['left']
-        else:
-            left = listin[index]['xmax']
+        print('\n[parser.py] __hor()')
+        '''
+        s = listindex[index]
 
+        If a horizontally overlaps a horizontal line hline, let a be the longest
+        horizontal line which overlaps hline, or hline if no horizontal line over-laps hline
+
+        If s is a horizontal line or bracket, 
+        START is called on the region defined by the wall attributes of s 
+        and the maxX bounding box coordinate of s (i.e. replacing leftWall)
+
+        The remaining cases simply require a scan of the input list, 
+        performing tests on 
+        >coordinate positions of s and the identity and coordinates< 
+        of each symbol encountered
+
+        A call is then made to OVERLAP (again, to check with overlap with horizontal lines).
+
+        In the general case, the leftmost symbol on the right of s in the HOR
+        region is returned as a if it is present and not overlapped by a horizontal
+        line.
+
+        For horizontal lines and open brackets, START is applied to the region
+        defined by the maxX bounding box coordinate of the symbol, and the re-maining three wall attributes.
+        '''
+
+        print('[parser.py] __hor() | symbol index: ', index)
+        print('[parser.py] __hor() | symbol label: ', listin[index]['label'])
+
+        # left = listin[index]['xmin']
+        left = listin[index]['wall']['left']
         right = listin[index]['wall']['right']
+        top = listin[index]['ymin'] + (listin[index]['h'] * (1/6))
+        bottom = listin[index]['ymin'] + (listin[index]['h'] * (5/6))
 
-        # Solve the region with "-", "." label 
-        if int(listin[index]['label']) in [10, 28]:
-            top = listin[index]['wall']['top']
-            bottom = listin[index]['wall']['bottom']
-        else:
-            # top = listin[index]['ymin'] + (listin[index]['h'] * (1/5.9))
-            top = listin[index]['ymin'] + (listin[index]['h'] * (1/6))
-            bottom = listin[index]['ymin'] + (listin[index]['h'] * (5/6))
-            # bottom = listin[index]['ymin'] + (listin[index]['h'] * (5/5.9))
 
-        helpers.debug('[parser.py] __hor() current symbol label: %s' % listin[index]['label'])
-        helpers.debug('[parser.py] __hor() symbol coordinates| xmin: %d, ymin: %d, xmax: %d, ymax: %d' % 
-            (
-                listin[index]['xmin'],
-                listin[index]['ymin'],
-                listin[index]['xmax'],
-                listin[index]['ymax']
-            )
-        )
-        helpers.debug('[parser.py] __hor() | top: %d, bottom: %d, left: %d, right: %d' % (top, bottom, left, right))
         global stop
         stop = False
-
-        c = 0
         global a
         a = -1
 
-        for s in range(0, len(listin)):
-            c += 1
-            if not stop:
+        label = int(listin[index]['label'])
+
+        if label == 23:
+            left = listin[index]['xmax']
+
+        if  label == 10 or label in range(28, 29, 30):
+            top = listin[index]['wall']['top']
+            bottom = listin[index]['wall']['bottom']
+
+        # if it is horizontal line or brackets
+        if label in range(10,17):
+            R = [[listin[index]['xmax'], top], [right, bottom]]
+            print('[parser.py] __hor() | R', R)
+            a = self.__start(listin, R)
+            stop = True
+        else:
+            helpers.debug('[parser.py] __hor() | top: %d, bottom: %d, left: %d, right: %d' % (top, bottom, left, right))
+            for s in range(0, len(listin)):
+
                 checked = listin[s]['checked']
                 if not checked:
                     symbol = listin[s]
@@ -347,30 +462,18 @@ class Parser:
                     helpers.debug('[parser.py] __hor() | ... symbol centroid: %s ' % symbol['centroid'])
                     helpers.debug('[parser.py] __hor() | ... symbol coordinates: %s %s %s %s' % (symbol['xmin'], symbol['xmax'], symbol['ymin'], symbol['ymax']))
 
-                    # if int(listin[index]['label']) in range(10,17):
-                    # if int(listin[index]['label']) in range(10,16): # vou testar assim
-                    if int(listin[index]['label']) in range(10,17) or int(listin[index]['label']) == 30: # mudei de volta 21/06 22:02 e adicionei o 30
-                        helpers.debug('[parser.py] __hor() | ...... before call start (11,18)')
-                        R = [[left, top], [right, bottom]]
-                        a = self.__start(listin, R)
-                        stop = True
-                    else: 
-                        helpers.debug('[parser.py] __hor() | ...... not(11,18)')
+                    # Adicionei o round() nos dois
+                    # Adicionei o >=, <=, ... - era só >, <, ...
+                    if round(symbol['centroid'][0]) >= round(left) and \
+                        round(symbol['centroid'][0]) <= round(right) and \
+                        round(symbol['centroid'][1]) <= round(bottom) and \
+                        round(symbol['centroid'][1]) >= round(top):
+                            helpers.debug('[parser.py] __hor() | ......... founded: %s' % s)
+                            a = s
+                            stop = True
+                            break
 
-                        # Adicionei o round() nos dois
-                        # Adicionei o >=, <=, ... - era só >, <, ...
-                        if round(symbol['centroid'][0]) >= round(left) and \
-                            round(symbol['centroid'][0]) <= round(right) and \
-                            round(symbol['centroid'][1]) <= round(bottom) and \
-                            round(symbol['centroid'][1]) >= round(top):
-                                helpers.debug('[parser.py] __hor() | ......... founded: %s' % s)
-                                a = s
-                                stop = True
-
-            helpers.debug('[parser.py] __hor() | a: %d ' % a)
-            helpers.debug('[parser.py] __hor() | stop: %s ' % stop)
-            if stop:
-                break
+                    helpers.debug('[parser.py] __hor() | a: %d ' % a)
 
         if a != -1:
             helpers.debug('[parser.py] __hor() | a label: %s ' % listin[a]['label'])
@@ -404,13 +507,13 @@ class Parser:
                 except BaseException as e:
                     print('Exception: ', e)
 
-            if current.node_type == 'RegionNode' or current.data['label'] == '23': # 23 sqrt
+            if current.node_type == 'RegionNode':
                 latex.append('{')
 
             for node in current.children:
                 recur(node)
 
-            if current.node_type == 'RegionNode' or current.data['label'] == '23': # 23 sqrt
+            if current.node_type == 'RegionNode':
                 latex.append('}')
 
         recur(node)
@@ -424,6 +527,7 @@ class Parser:
                 latex.pop()
                 latex.reverse()
 
+
         return latex
 
     def __list_to_latex_obj(self, tlist):
@@ -466,7 +570,60 @@ class Parser:
 
         subst = helpers.subst
 
-        eostring = len(latex)
+        latex = self.__token_substitution(latex, grammar, subst)
+
+        return latex
+
+    def __token_substitution(self, latex, grammar, subst):
+
+        def __list_substitution(i, nomatch, aux, initial_index, label, substitution_list, substitution_index):
+            for substitution in substitution_list[substitution_index]:
+                helpers.debug('[parser.py] __list_to_latex_obj() | ......substitution: ') # subsc
+                helpers.debug('[parser.py] __list_to_latex_obj() | ......latex index: %d ' % i) # subsc
+                helpers.debug(substitution) # subsc
+                try:
+                    helpers.debug('[parser.py] __list_to_latex_obj() | ......current latex: %s ' % latex[i]['label'])
+                    if latex[i]['label'] == substitution: # latex[i]['label'] = subst[subs][substitution]
+                        helpers.debug('[parser.py] __list_to_latex_obj() | ......match ')
+                        helpers.debug('[parser.py] __list_to_latex_obj() | ......from: %s %s ' % (latex[i]['label'], substitution))
+                        helpers.debug('[parser.py] __list_to_latex_obj() | ......to: %s ' % substitution_list[substitution_index][substitution])
+                        aux.append({"index": i, "label": substitution_list[substitution_index][substitution]})
+                        i += 1
+                    else:
+                        helpers.debug('[parser.py] __list_to_latex_obj() | ......no match ')
+                        i -= 1
+                        nomatch=True
+                except IndexError as e:
+                    helpers.debug('[parser.py] __list_to_latex_obj() | ......no match: IndexError ')
+                    nomatch=True
+                    break
+
+                helpers.debug('[parser.py] __list_to_latex_obj() | ...... no match value: %s ' % nomatch)
+                if nomatch:
+                    i = initial_index
+                    helpers.debug('[parser.py] __list_to_latex_obj() | ...... continue ......')
+                    break
+                helpers.debug('[parser.py] __list_to_latex_obj() | ...... next ......')
+            return i, nomatch
+
+        def __change_label(i, label, substitution_list):
+            for substitution_index in range(0, len(substitution_list)):
+                nomatch=False
+                aux = []
+
+                helpers.debug('[parser.py] __list_to_latex_obj() | ...substitutions: ')
+                helpers.debug(substitution_list[substitution_index])
+
+                initial_index = i # 9
+
+                i, nomatch = __list_substitution(i, nomatch, aux, initial_index, label, substitution_list, substitution_index)
+
+                if not nomatch:
+                    helpers.debug('[parser.py] __list_to_latex_obj() | match - updating value ')
+                    for matched in aux:
+                        latex[matched['index']]['label'] = matched['label']
+                return i
+
         for i in range(0, len(latex)):
             if latex[i]['label'] in grammar:
                 label = grammar[latex[i]['label']]
@@ -476,45 +633,7 @@ class Parser:
                     helpers.debug('[parser.py] __list_to_latex_obj() | substitution_list: ')
                     helpers.debug(substitution_list)
 
-                    for substitution_index in range(0, len(substitution_list)):
-                        nomatch=False
-                        aux = []
-
-                        helpers.debug('[parser.py] __list_to_latex_obj() | ...substitutions: ')
-                        helpers.debug(substitution_list[substitution_index])
-
-                        initial_index = i # 9
-                        for substitution in substitution_list[substitution_index]:
-                            helpers.debug('[parser.py] __list_to_latex_obj() | ......substitution: ') # subsc
-                            helpers.debug('[parser.py] __list_to_latex_obj() | ......latex index: %d ' % i) # subsc
-                            helpers.debug(substitution) # subsc
-                            try:
-                                helpers.debug('[parser.py] __list_to_latex_obj() | ......current latex: %s ' % latex[i]['label'])
-                                if latex[i]['label'] == substitution: # latex[i]['label'] = subst[subs][substitution]
-                                    helpers.debug('[parser.py] __list_to_latex_obj() | ......match ')
-                                    helpers.debug('[parser.py] __list_to_latex_obj() | ......from: %s %s ' % (latex[i]['label'], substitution))
-                                    helpers.debug('[parser.py] __list_to_latex_obj() | ......to: %s ' % substitution_list[substitution_index][substitution])
-                                    aux.append({"index": i, "label": substitution_list[substitution_index][substitution]})
-                                    i += 1
-                                else:
-                                    helpers.debug('[parser.py] __list_to_latex_obj() | ......no match ')
-                                    i -= 1
-                                    nomatch=True
-                            except IndexError as e:
-                                helpers.debug('[parser.py] __list_to_latex_obj() | ......no match: IndexError ')
-                                nomatch=True
-                                break
-
-                            helpers.debug('[parser.py] __list_to_latex_obj() | ...... no match value: %s ' % nomatch)
-                            if nomatch:
-                                i = initial_index
-                                helpers.debug('[parser.py] __list_to_latex_obj() | ...... continue ......')
-                                break
-                            helpers.debug('[parser.py] __list_to_latex_obj() | ...... next ......')
-                        if not nomatch:
-                            helpers.debug('[parser.py] __list_to_latex_obj() | match - updating value ')
-                            for matched in aux:
-                                latex[matched['index']]['label'] = matched['label']
+                    i = __change_label(i, label, substitution_list)
 
         return latex
 
